/*
  This file is part of GerPhys.

  GerPhys is free software: you can redistribute it and/or modify it under the
  terms of the GNU General Public License as published by the Free Software
  Foundation, either version 3 of the License, or (at your option) any later
  version.

  GerPhys is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
  A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with
  GerPhys.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef GERPH_R3MATRIX_H
#define GERPH_R3MATRIX_H


#include "r3vector.h"


namespace GerPh {


  class R3Matrix {

    public:

      R3Matrix();

      double getCoeff(int i, int j) const;
      void setCoeff(int i, int j, double aValue);

      void setM(
        double a00, double a01, double a02,
	double a10, double a11, double a12,
	double a20, double a21, double a22);

      R3Matrix transpose();

      bool operator== (const R3Matrix &M) { return isEqual(M); }
      R3Matrix& operator= (const R3Matrix &M) { return setEqual(M); }
      R3Matrix& operator+= (const R3Matrix &M) { return addMtx(M); }
      R3Matrix& operator-= (const R3Matrix &M) { return subMtx(M); }
      R3Matrix& operator*= (const R3Matrix &M) { return multMtx(M); }
      R3Matrix& operator*= (double x) { return multDbl(x); }
      R3Matrix& operator/= (double x) { return multDbl(1.0 / x); }

    private:

      double fCoeff[3][3];

      static void checkIdx(int i, int j);

      bool isEqual(const R3Matrix &M) const;
      R3Matrix& setEqual(const R3Matrix &M);
      R3Matrix& addMtx(const R3Matrix &M);
      R3Matrix& subMtx(const R3Matrix &M);
      R3Matrix& multMtx(const R3Matrix &M);
      R3Matrix& multDbl(double x);

  }; // R3Matrix


  R3Matrix operator+ (const R3Matrix &M1, const R3Matrix &M2);
  R3Matrix operator- (const R3Matrix &M1, const R3Matrix &M2);
  R3Matrix operator* (const R3Matrix &M1, const R3Matrix &M2);
  R3Matrix operator* (double x, const R3Matrix &M);
  R3Matrix operator* (const R3Matrix &M, double x);
  R3Matrix operator/ (const R3Matrix &M, double x);

  R3Vector operator* (const R3Matrix &M, const R3Vector &v);


} // GerPh


#endif
