/*
  This file is part of GerPhys.

  GerPhys is free software: you can redistribute it and/or modify it under the
  terms of the GNU General Public License as published by the Free Software
  Foundation, either version 3 of the License, or (at your option) any later
  version.

  GerPhys is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
  A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with
  GerPhys.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef GERPH_SI_H
#define GERPH_SI_H


namespace GerPh {


  class SI {

    public:

      static const double unit_nm;
      static const double unit_cm;
      static const double unit_m;
      static const double unit_km;
      static const double unit_ls;
      static const double unit_ly;

      static const double unit_m2;
      static const double unit_cm2;
      static const double unit_m3;
      static const double unit_cm3;

      static const double unit_g;
      static const double unit_kg;
      static const double unit_t;

      static const double unit_s;
      static const double unit_min;
      static const double unit_h;
      static const double unit_day;
      static const double unit_year;

      static const double unit_K;

      static const double unit_s2;

      static const double unit_km_s;

      static const double unit_g_cm3;

      static const double unit_kg_s;

      static const double unit_N;
      static const double unit_J;
      static const double unit_W;

      static const double unit_deg;
      static const double unit_arcmin;
      static const double unit_arcsec;

      static const double CONST_pi;
      static const double CONST_c;
      static const double CONST_h;
      static const double CONST_G;
      static const double CONST_g;
      static const double CONST_k;

      /*
        Conversion between radians and degrees + arcmin + arcsec:
      */
      static double ArcToRad(double aDeg, double aMin = 0.0, double aSec = 0.0);
      static void RadToArc(
        double aRad, double &aDeg, double &aMin, double &aSec);

      /*
        Conversion between radians and equatorial (astronomical) coordinates:
      */
      static double EqToRad(double aH, double aMin = 0.0, double aS = 0.0);
      static void RadToEq(double aRad, double &aH, double &aMin, double &aS);

  }; // SI


} // GerPh


#endif
